# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import user_service_pb2 as user__service__pb2


class UserStub:
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
            "/User/Create",
            request_serializer=user__service__pb2.CreateUserRequest.SerializeToString,
            response_deserializer=user__service__pb2.CreateUserResponse.FromString,
        )
        self.UpdatePassword = channel.unary_unary(
            "/User/UpdatePassword",
            request_serializer=user__service__pb2.UpdateUserPasswordRequest.SerializeToString,
            response_deserializer=user__service__pb2.UpdateUserPasswordResponse.FromString,
        )
        self.UpdateEmail = channel.unary_unary(
            "/User/UpdateEmail",
            request_serializer=user__service__pb2.UpdateUserEmailRequest.SerializeToString,
            response_deserializer=user__service__pb2.UpdateUserEmailResponse.FromString,
        )
        self.GetLoginHistory = channel.unary_unary(
            "/User/GetLoginHistory",
            request_serializer=user__service__pb2.GetUserLoginHistoryRequest.SerializeToString,
            response_deserializer=user__service__pb2.GetUserLoginHistoryResponse.FromString,
        )


class UserServicer:
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdatePassword(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLoginHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=user__service__pb2.CreateUserRequest.FromString,
            response_serializer=user__service__pb2.CreateUserResponse.SerializeToString,
        ),
        "UpdatePassword": grpc.unary_unary_rpc_method_handler(
            servicer.UpdatePassword,
            request_deserializer=user__service__pb2.UpdateUserPasswordRequest.FromString,
            response_serializer=user__service__pb2.UpdateUserPasswordResponse.SerializeToString,
        ),
        "UpdateEmail": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEmail,
            request_deserializer=user__service__pb2.UpdateUserEmailRequest.FromString,
            response_serializer=user__service__pb2.UpdateUserEmailResponse.SerializeToString,
        ),
        "GetLoginHistory": grpc.unary_unary_rpc_method_handler(
            servicer.GetLoginHistory,
            request_deserializer=user__service__pb2.GetUserLoginHistoryRequest.FromString,
            response_serializer=user__service__pb2.GetUserLoginHistoryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("User", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class User:
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/User/Create",
            user__service__pb2.CreateUserRequest.SerializeToString,
            user__service__pb2.CreateUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdatePassword(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/User/UpdatePassword",
            user__service__pb2.UpdateUserPasswordRequest.SerializeToString,
            user__service__pb2.UpdateUserPasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateEmail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/User/UpdateEmail",
            user__service__pb2.UpdateUserEmailRequest.SerializeToString,
            user__service__pb2.UpdateUserEmailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLoginHistory(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/User/GetLoginHistory",
            user__service__pb2.GetUserLoginHistoryRequest.SerializeToString,
            user__service__pb2.GetUserLoginHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12\x61uth_service.proto"/\n\x0cLoginRequest\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"d\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\t\x12\x12\n\ntoken_type\x18\x04 \x01(\t",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t"k\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\t\x12\x12\n\ntoken_type\x18\x04 \x01(\t"%\n\rLogoutRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x10\n\x0eLogoutResponse")\n\x11\x43heckTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t"\x14\n\x12\x43heckTokenResponse2\xcd\x01\n\x04\x41uth\x12&\n\x05Login\x12\r.LoginRequest\x1a\x0e.LoginResponse\x12;\n\x0cRefreshToken\x12\x14.RefreshTokenRequest\x1a\x15.RefreshTokenResponse\x12)\n\x06Logout\x12\x0e.LogoutRequest\x1a\x0f.LogoutResponse\x12\x35\n\nCheckToken\x12\x12.CheckTokenRequest\x1a\x13.CheckTokenResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "auth_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _LOGINREQUEST._serialized_start = 22
    _LOGINREQUEST._serialized_end = 69
    _LOGINRESPONSE._serialized_start = 71
    _LOGINRESPONSE._serialized_end = 171
    _REFRESHTOKENREQUEST._serialized_start = 173
    _REFRESHTOKENREQUEST._serialized_end = 217
    _REFRESHTOKENRESPONSE._serialized_start = 219
    _REFRESHTOKENRESPONSE._serialized_end = 326
    _LOGOUTREQUEST._serialized_start = 328
    _LOGOUTREQUEST._serialized_end = 365
    _LOGOUTRESPONSE._serialized_start = 367
    _LOGOUTRESPONSE._serialized_end = 383
    _CHECKTOKENREQUEST._serialized_start = 385
    _CHECKTOKENREQUEST._serialized_end = 426
    _CHECKTOKENRESPONSE._serialized_start = 428
    _CHECKTOKENRESPONSE._serialized_end = 448
    _AUTH._serialized_start = 451
    _AUTH._serialized_end = 656
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12user_service.proto"4\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"/\n\x12\x43reateUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t"C\n\x19UpdateUserPasswordRequest\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t"\x1c\n\x1aUpdateUserPasswordResponse"=\n\x16UpdateUserEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t"\x19\n\x17UpdateUserEmailResponse"Q\n\x1aGetUserLoginHistoryRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05"X\n\x10UserLoginHistory\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x12\n\nuser_agent\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t"A\n\x1bGetUserLoginHistoryResponse\x12"\n\x07results\x18\x01 \x03(\x0b\x32\x11.UserLoginHistory2\x94\x02\n\x04User\x12\x31\n\x06\x43reate\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12I\n\x0eUpdatePassword\x12\x1a.UpdateUserPasswordRequest\x1a\x1b.UpdateUserPasswordResponse\x12@\n\x0bUpdateEmail\x12\x17.UpdateUserEmailRequest\x1a\x18.UpdateUserEmailResponse\x12L\n\x0fGetLoginHistory\x12\x1b.GetUserLoginHistoryRequest\x1a\x1c.GetUserLoginHistoryResponseb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "user_service_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS is False:

    DESCRIPTOR._options = None
    _CREATEUSERREQUEST._serialized_start = 22
    _CREATEUSERREQUEST._serialized_end = 74
    _CREATEUSERRESPONSE._serialized_start = 76
    _CREATEUSERRESPONSE._serialized_end = 123
    _UPDATEUSERPASSWORDREQUEST._serialized_start = 125
    _UPDATEUSERPASSWORDREQUEST._serialized_end = 192
    _UPDATEUSERPASSWORDRESPONSE._serialized_start = 194
    _UPDATEUSERPASSWORDRESPONSE._serialized_end = 222
    _UPDATEUSEREMAILREQUEST._serialized_start = 224
    _UPDATEUSEREMAILREQUEST._serialized_end = 285
    _UPDATEUSEREMAILRESPONSE._serialized_start = 287
    _UPDATEUSEREMAILRESPONSE._serialized_end = 312
    _GETUSERLOGINHISTORYREQUEST._serialized_start = 314
    _GETUSERLOGINHISTORYREQUEST._serialized_end = 395
    _USERLOGINHISTORY._serialized_start = 397
    _USERLOGINHISTORY._serialized_end = 485
    _GETUSERLOGINHISTORYRESPONSE._serialized_start = 487
    _GETUSERLOGINHISTORYRESPONSE._serialized_end = 552
    _USER._serialized_start = 555
    _USER._serialized_end = 831
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import auth_service_pb2 as auth__service__pb2


class AuthStub:
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Login = channel.unary_unary(
            "/Auth/Login",
            request_serializer=auth__service__pb2.LoginRequest.SerializeToString,
            response_deserializer=auth__service__pb2.LoginResponse.FromString,
        )
        self.RefreshToken = channel.unary_unary(
            "/Auth/RefreshToken",
            request_serializer=auth__service__pb2.RefreshTokenRequest.SerializeToString,
            response_deserializer=auth__service__pb2.RefreshTokenResponse.FromString,
        )
        self.Logout = channel.unary_unary(
            "/Auth/Logout",
            request_serializer=auth__service__pb2.LogoutRequest.SerializeToString,
            response_deserializer=auth__service__pb2.LogoutResponse.FromString,
        )
        self.CheckToken = channel.unary_unary(
            "/Auth/CheckToken",
            request_serializer=auth__service__pb2.CheckTokenRequest.SerializeToString,
            response_deserializer=auth__service__pb2.CheckTokenResponse.FromString,
        )


class AuthServicer:
    """Missing associated documentation comment in .proto file."""

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CheckToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Login": grpc.unary_unary_rpc_method_handler(
            servicer.Login,
            request_deserializer=auth__service__pb2.LoginRequest.FromString,
            response_serializer=auth__service__pb2.LoginResponse.SerializeToString,
        ),
        "RefreshToken": grpc.unary_unary_rpc_method_handler(
            servicer.RefreshToken,
            request_deserializer=auth__service__pb2.RefreshTokenRequest.FromString,
            response_serializer=auth__service__pb2.RefreshTokenResponse.SerializeToString,
        ),
        "Logout": grpc.unary_unary_rpc_method_handler(
            servicer.Logout,
            request_deserializer=auth__service__pb2.LogoutRequest.FromString,
            response_serializer=auth__service__pb2.LogoutResponse.SerializeToString,
        ),
        "CheckToken": grpc.unary_unary_rpc_method_handler(
            servicer.CheckToken,
            request_deserializer=auth__service__pb2.CheckTokenRequest.FromString,
            response_serializer=auth__service__pb2.CheckTokenResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("Auth", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Auth:
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Login(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Auth/Login",
            auth__service__pb2.LoginRequest.SerializeToString,
            auth__service__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RefreshToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Auth/RefreshToken",
            auth__service__pb2.RefreshTokenRequest.SerializeToString,
            auth__service__pb2.RefreshTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Logout(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Auth/Logout",
            auth__service__pb2.LogoutRequest.SerializeToString,
            auth__service__pb2.LogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CheckToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/Auth/CheckToken",
            auth__service__pb2.CheckTokenRequest.SerializeToString,
            auth__service__pb2.CheckTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class CreateUserRequest(_message.Message):
    __slots__ = ["email", "password"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CreateUserResponse(_message.Message):
    __slots__ = ["email", "id"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class GetUserLoginHistoryRequest(_message.Message):
    __slots__ = ["access_token", "limit", "offset"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    limit: int
    offset: int
    def __init__(
        self,
        access_token: _Optional[str] = ...,
        limit: _Optional[int] = ...,
        offset: _Optional[int] = ...,
    ) -> None: ...

class GetUserLoginHistoryResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[UserLoginHistory]
    def __init__(self, results: _Optional[_Iterable[_Union[UserLoginHistory, _Mapping]]] = ...) -> None: ...

class UpdateUserEmailRequest(_message.Message):
    __slots__ = ["access_token", "email"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    email: str
    def __init__(self, email: _Optional[str] = ..., access_token: _Optional[str] = ...) -> None: ...

class UpdateUserEmailResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateUserPasswordRequest(_message.Message):
    __slots__ = ["access_token", "password"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    password: str
    def __init__(self, password: _Optional[str] = ..., access_token: _Optional[str] = ...) -> None: ...

class UpdateUserPasswordResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UserLoginHistory(_message.Message):
    __slots__ = ["date", "device", "ip_address", "user_agent"]
    DATE_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    date: str
    device: str
    ip_address: str
    user_agent: str
    def __init__(
        self,
        date: _Optional[str] = ...,
        ip_address: _Optional[str] = ...,
        user_agent: _Optional[str] = ...,
        device: _Optional[str] = ...,
    ) -> None: ...
